#!/usr/bin/perl
# --
# LinkCIs.pl - link HW CI to SW CI
# Copyright (C) 2014 WUERTH PHOENIX, http://www.wuerth-phoenix.com/
# --
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU AFFERO General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# or see http://www.gnu.org/licenses/agpl.txt.
# --

use strict;
use warnings;

use lib "/opt/otrs/";
use lib "/opt/otrs/Kernel/cpan-lib";


use Kernel::Config;
use Kernel::System::DB;
use Kernel::System::Encode;
use Kernel::System::Ticket;
use Kernel::System::Time;
use Kernel::System::Log;
use Kernel::System::Main;
use Kernel::System::LinkObject;
use Kernel::System::ITSMConfigItem;


my %CommonObject;
$CommonObject{ConfigObject} = Kernel::Config->new();
$CommonObject{LogObject}    = Kernel::System::Log->new(
    LogPrefix => 'OTRS-OCS',
    %CommonObject,
);
$CommonObject{EncodeObject}       = Kernel::System::Encode->new(%CommonObject);
$CommonObject{MainObject}         = Kernel::System::Main->new(%CommonObject);
$CommonObject{TimeObject}         = Kernel::System::Time->new(%CommonObject);
$CommonObject{DBObject}           = Kernel::System::DB->new(%CommonObject);
$CommonObject{TicketObject} 	  = Kernel::System::Ticket->new(%CommonObject);
$CommonObject{LinkObject}         = Kernel::System::LinkObject->new(%CommonObject);
$CommonObject{ConfigItemObject}   = Kernel::System::ITSMConfigItem->new( %CommonObject );

my $FileName = $ARGV[0];
if( !$FileName || ! -f $FileName){
        print "Usage: LinkCIs.pl file.csv\n";
        print "csv format: id,name hw,name sw\n";
        exit (1);
}

open FILE, $FileName or die $!;
while (<FILE>) {
	chomp($_);
	my @FIELDS = split ",", $_;
	 $CommonObject{LogObject}->Log(
	            Priority => 'notice',
        	    Message  => "HW:$FIELDS[1]|SW:$FIELDS[2]|",
	);
	my $HW = $CommonObject{ConfigItemObject}->ConfigItemSearchExtended(
		Name => $FIELDS[1],
	);
	my $SW = $CommonObject{ConfigItemObject}->ConfigItemSearchExtended(
		Name => $FIELDS[2],
	);

	if( $HW && ref $HW eq 'ARRAY' && @{$HW} && $SW && ref $SW  eq 'ARRAY' && @{$SW}) {
		my $LinkResult = $CommonObject{LinkObject}->LinkAdd(
			SourceObject => 'ITSMConfigItem',
			SourceKey => @{$SW}[0],
			TargetObject => 'ITSMConfigItem',
			TargetKey => @{$HW}[0],
			Type => 'RelevantTo',
			State => 'Valid',
			UserID => 1,
		);
	}
}
close FILE;
